@@ -30,5 +30,12 @@ class ThemeFunctionalTest(ThemeBaseCase):
         json_data = self.assertResponse()
         tab_logo_path = json_data.get("data").get("tab_logo")
         self.assertTrue(
-             tab_logo_path.startswith("/theme/theme"), msg=tab_logo_path
+            tab_logo_path.startswith("/theme/theme"), msg=tab_logo_path
+        )
+
+    def test_get_login_logo(self):
+        json_data = self.assertResponse()
+        login_logo_path = json_data.get("data").get("login_logo")
+        self.assertTrue(
+            login_logo_path.startswith("/theme/theme"), msg=login_logo_path
         )
